#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#    This file is part of Bakara. <https://github.com/salosh/bakara.git>
#
#    Bakara is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Bakara is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Bakara.  If not, see <http://www.gnu.org/licenses/>.
#
from __future__ import unicode_literals

__author__ = 'saloshp'
__author_email__ = 'support@salosh.org'
__license__ = 'GPLv3'
__maintainer_email__ = 'support@salosh.org'
__url__ = 'https://github.com/salosh/bakara.git'
__version__ = '0.0.1'

import sys

def main(argv=None):
    sys.exit(0)

__all__ = ()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#    This file is part of Bakara. <https://github.com/salosh/bakara.git>
#
#    Bakara is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Bakara is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Bakara.  If not, see <http://www.gnu.org/licenses/>.
#

from __future__ import unicode_literals
import sys

if __package__ is None and not hasattr(sys, 'frozen'):
    # direct calling to __main__.py
    import os.path
    path = os.path.realpath(os.path.abspath(__file__))
    sys.path.insert(0, os.path.dirname(os.path.dirname(path)))

import bakara

if __name__ == '__main__':
    bakara.main()
